.. _optimizations:

Optimization
============

.. py:module:: ansys.simai.core.data.optimizations

Directory
---------

.. autoclass:: OptimizationDirectory()
    :members:

Model
-----

.. autoclass:: Optimization()
    :members:
    :inherited-members:

..
   TrialRuns
   =========

   Trial runs are a single step of the optimization process.

   Directory
   ---------

   .. autoclass:: __OptimizationTrialRunDirectory()
       :members:


   Model
   -----

   .. autoclass:: __OptimizationTrialRun()
       :members:
       :inherited-members:

.. autoclass:: OptimizationResult()
    :members:
